import { Observable } from 'rxjs';
import { FeatureFlagStore } from "./feature-flag-store";
import * as i0 from "@angular/core";
export type LogicalOperator = 'AND' | 'OR';
export declare class FeatureFlagsService<F = string> {
    private monitor;
    monitor$: Observable<F>;
    private featureFlags;
    featureFlags$: Observable<Set<F>>;
    constructor(featureStore: FeatureFlagStore<F>);
    /**
     * Returns true if the featureflag is turned off, false if it is turned off.
     * Preference is to use featureOff$ and use the observable when possibe.
     * @param {any} featureFlags:string|string[]
     * @param {any} operator:LogicalOperator='AND' operator to use, 'AND' or 'OR'
     * @returns {boolean} boolean true if the feature is off, false if the featureflag is not available
     */
    featureOff(featureFlags: F, operator?: LogicalOperator): boolean;
    /**
     * Check if the feature flag or set of featureflags of turned off
     * @param {any} featureFlags:string|string[]
     * @param {any} operator:LogicalOperator='AND' operator to use, 'AND' or 'OR'
     * @returns {boolean} Observable<boolean> true if the feature/feature set with condition is off
     */
    featureOff$(featureFlags: F, operator?: LogicalOperator): Observable<boolean>;
    /**
     * Returns true if the featureflag is turned on, false if it is turned on.
     * Preference is to use featureOn$ and use the observable when possibe.
     * @param {any} featureFlags:string|string[]
     * @param {any} operator:LogicalOperator='AND' operator to use, 'AND' or 'OR'
     * @returns {boolean} boolean true if the feature is on, false if the featureflag is not available
     */
    featureOn(featureFlags: F, operator?: LogicalOperator): boolean;
    /**
     * Check if the feature flag or set of featureflags of turned on
     * @param {any} featureFlags:string|string[]
     * @param {any} operator:LogicalOperator='AND' operator to use, 'AND' or 'OR'
     * @returns {boolean} Observable<boolean> true if the feature/feature set with condition is on
     */
    featureOn$(featureFlags: F, operator?: LogicalOperator): Observable<boolean>;
    prev: F[];
    /**
     * Trace feature usage
     * @param {any} featureTrace:string
     * @returns {void}
     */
    featureTrace(featureTrace: F): void;
    featureUsageTrace(featureTrace: F): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FeatureFlagsService<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FeatureFlagsService<any>>;
}
